@@ -33,7 +33,7 @@ defined('_JEXEC') or die('Restricted access');
 JToolBarHelper::title(JText::_('Registration') . ': <small><small>[ ' . JText::_('Incremental Registration Options') . ' ]</small></small>', 'user.png');
 JToolBarHelper::save();
 
-$dbh = JFactory::getDBO();
+$dbh =& JFactory::getDBO();
 $dbh->setQuery('SELECT popover_text, award_per, test_group FROM #__incremental_registration_options ORDER BY added DESC LIMIT 1');
 list($popoverText, $awardPer, $testGroup) = $dbh->loadRow();
 $dbh->setQuery('SELECT hours FROM #__incremental_registration_popover_recurrence ORDER BY idx');
@@ -45,142 +45,11 @@ $possibleCols = $groups->getPossibleColumns();
 $groupDefs = $groups->getAllGroups();
 ?>
 <script type="text/javascript">
-	var possibleCols = <?php echo json_encode($possibleCols); ?>;
+	window.possibleCols = <?php echo json_encode($possibleCols); ?>;
 	
 	function submitbutton(pressbutton) {
 		submitform(pressbutton);
 	}
-	var addField = function(that, idx) {
-		var li = document.createElement('li');
-		var ul = that.previousSibling;
-		while (ul.tagName != 'UL') {
-			ul = ul.previousSibling;
-		}
-		
-		var sel = document.createElement('select');
-		sel.setAttribute('style', 'width: 300px');
-		var opt = document.createElement('option');
-		opt.setAttribute('value', '');
-		opt.appendChild(document.createTextNode('Select profile field...'));
-		sel.appendChild(opt);
-		for (var k in possibleCols) {
-			if (possibleCols.hasOwnProperty(k)) {
-				opt = document.createElement('option');
-				opt.setAttribute('value', k);
-				opt.appendChild(document.createTextNode(possibleCols[k]));
-				sel.appendChild(opt);
-			}
-		}
-		sel.setAttribute('name', 'group-cols-' + idx + '[]');
-		li.appendChild(sel);
-		var rm = document.createElement('button');
-		rm.appendChild(document.createTextNode('Remove field'));
-		rm.onclick = function() {
-			ul.removeChild(li);
-			return false;
-		};
-		li.appendChild(rm);
-		ul.appendChild(li);
-	};
-
-	var renumberGroups = function() {
-		var lis = document.getElementById('reg-groups').getElementsByTagName('li');
-		var idx = 0;
-		for (var lidx = 0; lidx < lis.length; ++lidx) {
-			if (lis[lidx].getAttribute('class') == 'reg-group') {
-				var li = lis[lidx];
-				var inps = li.getElementsByTagName('input');
-				for (var sidx = 0; sidx < inps.length; ++sidx) {
-					inps[sidx].setAttribute('name', inps[sidx].getAttribute('name').replace(/\d+$/, idx));
-				}
-				var sels = li.getElementsByTagName('select');
-				for (var sidx = 0; sidx < sels.length; ++sidx) {
-					sels[sidx].setAttribute('name', sels[sidx].getAttribute('name').replace(/\d+(\[\])?$/, idx + '$1'));
-				}
-				var buts = li.getElementsByTagName('button');
-				for (var sidx = 0; sidx < buts.length; ++sidx) {
-					if (buts[sidx].getAttribute('class') == 'add-field') {
-						buts[sidx].onclick = function() {
-							addField(this, idx - 1);
-							return false;	
-						};
-					}
-				}
-				++idx;
-			}
-		}
-	};
-
-	var addGroup = function(that) {
-		var li = document.createElement('li');
-		li.setAttribute('class', 'reg-group');
-		var ol = that.parentNode;
-		while (ol.tagName != 'OL') {
-			ol = ol.previousSibling;
-		}
-		var p = document.createElement('p');
-		li.appendChild(p);
-		ol.appendChild(li);
-		p.appendChild(document.createTextNode('Beginning '));
-		var hours = document.createElement('input');
-		hours.setAttribute('name', 'group-hours-0');
-		hours.setAttribute('style', 'width: 40px');
-		p.appendChild(hours);	
-		var unit = document.createElement('select');
-		unit.setAttribute('name', 'group-time-unit-0');
-		unit.setAttribute('style', 'width: 100px');
-		var units = ['hour', 'day', 'week'];
-		for (var idx = 0; idx < units.length; ++idx) {
-			var opt = document.createElement('option');
-			opt.setAttribute('value', units[idx]);
-			opt.appendChild(document.createTextNode(units[idx] + 's'));
-			unit.appendChild(opt);
-		}
-		p.appendChild(unit);
-		p.appendChild(document.createTextNode(' after registration, prompt for: '));
-		var fields = document.createElement('ul');
-		fields.setAttribute('style', 'margin-top: 0; margin-left: 40px; margin-bottom: 0');
-		var fieldLi = document.createElement('li');
-		fields.appendChild(fieldLi);	
-		var fieldSel = document.createElement('select');
-		fieldSel.setAttribute('name', 'group-cols-0[]');
-		fieldSel.setAttribute('style', 'width: 300px');
-		var opt = document.createElement('option');
-		opt.appendChild(document.createTextNode('Select profile field...'));
-		fieldSel.appendChild(opt);
-		for (var k in possibleCols) {
-			if (possibleCols.hasOwnProperty(k)) {
-				opt = document.createElement('option');
-				opt.setAttribute('value', k);
-				opt.appendChild(document.createTextNode(possibleCols[k]));
-				fieldSel.appendChild(opt);
-			}
-		}
-		var fieldRm = document.createElement('button');
-		fieldRm.appendChild(document.createTextNode('Remove field'));
-		fieldRm.onclick = function() {
-			fields.removeChild(fieldLi);
-		};
-		fieldLi.appendChild(fieldSel);
-		fieldLi.appendChild(fieldRm);
-		p.appendChild(fields);
-		
-		var af = document.createElement('button');
-		af.setAttribute('class', 'add-field');
-		af.appendChild(document.createTextNode('Add field'));
-		af.setAttribute('style', 'margin-left: 40px');
-		p.appendChild(af);
-		
-		var rm = document.createElement('button');
-		rm.setAttribute('style', 'margin-bottom: 30px');
-		rm.appendChild(document.createTextNode('Remove group'));
-		rm.onclick = function() {
-			ol.removeChild(li);
-			renumberGroups();	
-		};	
-		li.appendChild(rm);
-		renumberGroups();
-	}
 </script>
 <form action="index.php" method="post" name="adminForm">
 	<fieldset class="adminform">
@@ -209,7 +78,7 @@ $groupDefs = $groups->getAllGroups();
 					<td class="key">Field groups</td>
 					<td>
 						<p>Packages of profile information to prompt starting some time after registration</p>
-						<ol id="reg-groups" style="margin:0 0 0 30px;">
+						<ol style="margin:0 0 0 30px;">
 							<?php 
 								foreach ($groupDefs as $idx=>$group): 
 									$unit = 'hour';
@@ -221,7 +90,7 @@ $groupDefs = $groups->getAllGroups();
 										$group['hours'] /= 24;
 									endif;
 							?>
-							<li class="reg-group">
+							<li>
 								<p>
 									Beginning <input name="group-hours-<?php echo $idx; ?>" value="<?php echo $group['hours']; ?>" style="width: 40px;" />
 									<select name="group-time-unit-<?php echo $idx; ?>" style="width: 100px;">
@@ -238,18 +107,48 @@ $groupDefs = $groups->getAllGroups();
 												<option value="<?php echo str_replace('"', '&quot;', $colName); ?>"<?php if ($colName == $col) echo ' selected="selected"'; ?>><?php echo htmlentities($colLabel); ?></option>	
 											<?php endforeach; ?>
 											</select>
-											<button onclick="this.parentNode.parentNode.removeChild(this.parentNode); return false">Remove field</button>
+											<button onclick="this.parentNode.parentNode.removeChild(this.parentNode); return false">Remove</button>
 										</li>
 										<?php endforeach; ?>
 									</ul>
-									<button class="add-field" style="margin-left: 40px;" onclick="addField(this, <?php echo $idx; ?>); return false;">Add field</button>
+									<button style="margin-left: 40px;" onclick="(function(that) { 			
+										var li = document.createElement('li');
+										var ul = that.previousSibling;
+										while (ul.tagName != 'UL') {
+											ul = ul.previousSibling;
+										}
+										var sel = document.createElement('select');
+										sel.setAttribute('style', 'width: 300px');
+										var opt = document.createElement('option');
+										opt.setAttribute('value', '');
+										opt.appendChild(document.createTextNode('Select profile field...'));
+										sel.appendChild(opt);
+										for (var k in possibleCols) {
+											if (possibleCols.hasOwnProperty(k)) {
+												opt = document.createElement('option');
+												opt.setAttribute('value', k);
+												opt.appendChild(document.createTextNode(possibleCols[k]));
+												sel.appendChild(opt);
+											}
+										}
+										sel.setAttribute('name', 'group-cols-<?php echo $idx; ?>');
+										li.appendChild(sel);
+
+										var rm = document.createElement('button');
+										rm.appendChild(document.createTextNode('Remove'));
+										rm.onclick = function() {
+											ul.removeChild(li);
+											return false;
+										};
+										li.appendChild(rm);
+										ul.appendChild(li);
+									})(this); return false;">Add field</button>
 								</p>
-								<button onclick="this.parentNode.parentNode.removeChild(this.parentNode); renumberGroups(); return false;" style="margin-bottom: 30px">Remove group</button>
 							</li>
 							<?php endforeach; ?>
 						</ol>
 						<p>
-							<button onclick="addGroup(this); return false;">Add group</button>
+							<button onclick="return false;">Add group</button>
 						</p>
 					</td>
 				</tr>
@@ -276,7 +175,7 @@ $groupDefs = $groups->getAllGroups();
 									<option value="day" <?php if ($unit == 'day') echo 'selected="selected" '; ?>>days</option>
 									<option value="week" <?php if ($unit == 'week') echo 'selected="selected" '; ?>>weeks</option>
 								</select>
-								<button onclick="this.parentNode.parentNode.removeChild(this.parentNode); return false">Remove recurrence</button>
+								<button onclick="this.parentNode.parentNode.removeChild(this.parentNode); return false">Remove</button>
 							</li>
 							<?php 
 								endforeach; 
@@ -305,7 +204,7 @@ $groupDefs = $groups->getAllGroups();
 							}
 							li.appendChild(sel);
 							var rm = document.createElement('button');
-							rm.appendChild(document.createTextNode('Remove field'));
+							rm.appendChild(document.createTextNode('Remove'));
 							rm.onclick = function() {
 								ol.removeChild(li);
 								return false;
