@@ -32,95 +32,88 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-include_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'models' . DS . 'middleware.php');
-include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_tools' . DS . 'tables' . DS . 'version.zones.php');
+ximport('Hubzero_Tool');
+ximport('Hubzero_Tool_Version');
+ximport('Hubzero_Controller');
 
 /**
- * Tools controller class for tool versions
+ * Short description for 'ContribtoolController'
+ * 
+ * Long description (if any) ...
  */
-class ToolsControllerVersions extends \Hubzero\Component\AdminController
+class ToolsControllerVersions extends Hubzero_Controller
 {
 	/**
 	 * Display all versions for a specific entry
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function displayTask()
 	{
 		// Push some styles to the template
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components' . DS . $this->_option . DS . 'tools.css');
 
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Get Filters
 		$this->view->filters = array();
 		$this->view->filters['id']          = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.versions.id',
-			'id',
+			$this->_option . '.' . $this->_controller . '.versions.id', 
+			'id', 
 			0,
 			'int'
 		);
 
 		// Get filters
-		/*$this->view->filters['search']       = urldecode($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.versions.' . $this->view->filters['id'] . 'search',
-			'search',
+		$this->view->filters['search']       = urldecode($app->getUserStateFromRequest(
+			$this->_option . '.' . $this->_controller . '.versions.search', 
+			'search', 
 			''
 		));
 		$this->view->filters['search_field'] = urldecode($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.versions.' . $this->view->filters['id'] . 'search_field',
-			'search_field',
+			$this->_option . '.' . $this->_controller . '.versions.search_field', 
+			'search_field', 
 			'all'
-		));*/
-
+		));
+		
 		// Sorting
 		$this->view->filters['sort']         = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.versions.' . $this->view->filters['id'] . 'sort',
-			'filter_order',
+			$this->_option . '.' . $this->_controller . '.versions.sort', 
+			'filter_order', 
 			'toolname'
 		));
 		$this->view->filters['sort_Dir']     = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.versions.' . $this->view->filters['id'] . 'sortdir',
-			'filter_order_Dir',
+			$this->_option . '.' . $this->_controller . '.versions.sortdir', 
+			'filter_order_Dir', 
 			'ASC'
 		));
 		$this->view->filters['sortby'] = $this->view->filters['sort'] . ' ' . $this->view->filters['sort_Dir'];
 
 		// Get paging variables
 		$this->view->filters['limit']        = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.versions.' . $this->view->filters['id'] . 'limit',
-			'limit',
-			$config->getValue('config.list_limit'),
+			$this->_option . '.' . $this->_controller . '.versions.limit', 
+			'limit', 
+			$config->getValue('config.list_limit'), 
 			'int'
 		);
 		$this->view->filters['start']        = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.versions.' . $this->view->filters['id'] . 'limitstart',
-			'limitstart',
-			0,
+			$this->_option . '.' . $this->_controller . '.versions.limitstart', 
+			'limitstart', 
+			0, 
 			'int'
 		);
-		// In case limit has been changed, adjust limitstart accordingly
-		$this->view->filters['start'] = ($this->view->filters['limit'] != 0 ? (floor($this->view->filters['start'] / $this->view->filters['limit']) * $this->view->filters['limit']) : 0);
-
-		if (!$this->view->filters['id'])
-		{
-			JError::raiseError(404, JText::_('COM_TOOLS_ERROR_MISSING_ID'));
-		}
-		$this->view->tool = ToolsModelTool::getInstance($this->view->filters['id']);
-		if (!$this->view->tool)
-		{
-			JError::raiseError(404, JText::_('COM_TOOLS_ERROR_TOOL_NOT_FOUND'));
-		}
+		
+		$this->view->tool = Hubzero_Tool::getInstance($this->view->filters['id']);
 		$this->view->total = count($this->view->tool->version);
 		$this->view->rows = $this->view->tool->getToolVersionSummaries($this->view->filters, true);
-
+		
 		// Initiate paging
 		jimport('joomla.html.pagination');
 		$this->view->pageNav = new JPagination(
-			$this->view->total,
-			$this->view->filters['start'],
+			$this->view->total, 
+			$this->view->filters['start'], 
 			$this->view->filters['limit']
 		);
 
@@ -139,27 +132,27 @@ class ToolsControllerVersions extends \Hubzero\Component\AdminController
 
 	/**
 	 * Edit an entry version
-	 *
+	 * 
 	 * @return     unknown Return description (if any) ...
 	 */
 	public function editTask()
 	{
 		JRequest::setVar('hidemainmenu', 1);
-
+		
 		// Incoming instance ID
 		$id = JRequest::getInt('id', 0);
 		$version = JRequest::getInt('version', 0);
 
 		// Do we have an ID?
-		if (!$id || !$version)
+		if (!$id || !$version) 
 		{
 			$this->cancelTask();
 			return;
 		}
 
-		$this->view->parent = ToolsModelTool::getInstance($id);
+		$this->view->parent = Hubzero_Tool::getInstance($id);
 
-		$this->view->row = ToolsModelVersion::getInstance($version);
+		$this->view->row = Hubzero_Tool_Version::getInstance($version);
 
 		// Set any errors
 		if ($this->getError())
@@ -176,7 +169,7 @@ class ToolsControllerVersions extends \Hubzero\Component\AdminController
 
 	/**
 	 * Save an entry version and show the edit form
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function applyTask()
@@ -186,7 +179,7 @@ class ToolsControllerVersions extends \Hubzero\Component\AdminController
 
 	/**
 	 * Save an entry version
-	 *
+	 * 
 	 * @param      boolean $redirect Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
@@ -196,65 +189,75 @@ class ToolsControllerVersions extends \Hubzero\Component\AdminController
 		$fields = JRequest::getVar('fields', array(), 'post');
 
 		// Do we have an ID?
-		if (!$fields['version'])
+		if (!$fields['version']) 
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('COM_TOOLS_ERROR_MISSING_ID'),
+				JText::_('Missing ID'),
 				'error'
 			);
 			return;
 		}
-
-		$row = ToolsModelVersion::getInstance(intval($fields['version']));
+		
+		$row = Hubzero_Tool_Version::getInstance(intval($fields['version']));
 		if (!$row)
 		{
 			JRequest::setVar('id', $fields['id']);
-			JRequest::setVar('version', $fields['version']);
-			$this->addComponentMessage(JText::_('COM_TOOLS_ERROR_TOOL_NOT_FOUND'), 'error');
+			JRequest::setVar('vserion', $fields['version']);
+			$this->addComponentMessage(JText::_('Tool instance not found'), 'error');
 			$this->editTask();
 			return;
 		}
 
 		$row->vnc_command = trim($fields['vnc_command']);
-		$row->vnc_timeout = ($fields['vnc_timeout'] != 0) ? intval(trim($fields['vnc_timeout'])) : NULL;
-		$row->hostreq     = trim($fields['hostreq']);
-		$row->mw          = trim($fields['mw']);
-		$row->params      = trim($fields['params']);
+		$row->vnc_timeout = intval(trim($fields['vnc_command']));
+		$row->hostreq = trim($fields['hostreq']);
 
 		if (!$row->vnc_command)
 		{
-			$this->addComponentMessage(JText::_('COM_TOOLS_ERROR_MISSING_COMMAND'), 'error');
+			$this->addComponentMessage(JText::_('No command value'), 'error');
+			$this->editTask($row);
+			return;
+		}
+		if (!$row->vnc_timeout && $row->vnc_timeout !== 0)
+		{
+			$this->addComponentMessage(JText::_('No timeout value'), 'error');
+			$this->editTask($row);
+			return;
+		}
+		if (!$row->hostreq)
+		{
+			$this->addComponentMessage(JText::_('No hostreq value'), 'error');
 			$this->editTask($row);
 			return;
 		}
 
-		$row->hostreq = (is_array($row->hostreq) ? explode(',', $row->hostreq[0]) : explode(',', $row->hostreq));
+		$row->hostreq = explode(',', $row->hostreq);
 
 		$hostreq = array();
 		foreach ($row->hostreq as $req)
 		{
 			if (!empty($req))
 			{
-				$hostreq[] = trim($req);
+			    $hostreq[] = $req;
 			}
 		}
 
 		$row->hostreq = $hostreq;
 		$row->update();
 
-		if ($this->_task == 'apply')
+		if ($this->_task == 'apply') 
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&task=edit&id=' . $fields['id'] . '&version=' . $fields['version']
 			);
 			return;
 		}
-		else
+		else 
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('COM_TOOLS_ITEM_SAVED')
+				JText::_('TOOL_VERSION_SAVED')
 			);
 		}
 	}
@@ -270,170 +273,4 @@ class ToolsControllerVersions extends \Hubzero\Component\AdminController
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller
 		);
 	}
-
-	/**
-	 * Display a list of version zones
-	 *
-	 * @return     void
-	 */
-	public function displayZonesTask()
-	{
-		$this->view->setLayout('component');
-
-		// Get the version number
-		$version = JRequest::getInt('version', 0);
-
-		// Do we have an ID?
-		if (!$version)
-		{
-			$this->cancelTask();
-			return;
-		}
-
-		// Get the table
-		$db = \JFactory::getDbo();
-		$this->view->rows    = with(new ToolVersionZones($db))->loadByToolVersion($version);
-		$this->view->version = $version;
-
-		// Set any errors
-		if ($this->getError())
-		{
-			foreach ($this->getErrors() as $error)
-			{
-				$this->view->setError($error);
-			}
-		}
-
-		// Display results
-		$this->view->display();
-	}
-
-	/**
-	 * Add a new zone
-	 *
-	 * @return     void
-	 */
-	public function addZoneTask()
-	{
-		$this->editZoneTask();
-	}
-
-	/**
-	 * Edit a zone
-	 *
-	 * @return     void
-	 */
-	public function editZoneTask($row=null)
-	{
-		JRequest::setVar('hidemainmenu', 1);
-
-		$this->view->setLayout('editZone');
-
-		if (is_object($row))
-		{
-			$this->view->row = $row;
-		}
-		else
-		{
-			// Incoming
-			$id = JRequest::getInt('id', 0);
-			$db = \JFactory::getDbo();
-			$this->view->row = new ToolVersionZones($db);
-			$this->view->row->load($id);
-		}
-
-		if (!$this->view->row->get('tool_version_id'))
-		{
-			$this->view->row->set('tool_version_id', \JRequest::getInt('version', 0));
-		}
-
-		// Set any errors
-		if ($this->getError())
-		{
-			foreach ($this->getErrors() as $error)
-			{
-				$this->view->setError($error);
-			}
-		}
-
-		// Display results
-		$this->view->display();
-	}
-
-	/**
-	 * Save changes to version zone
-	 *
-	 * @return     void
-	 */
-	public function saveZoneTask()
-	{
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
-		// Incoming
-		$fields = JRequest::getVar('fields', array(), 'post');
-
-		$db  = \JFactory::getDbo();
-		$row = new ToolVersionZones($db);
-
-		if (empty($fields['publish_up'])) $fields['publish_up'] = null;
-		if (empty($fields['publish_down'])) $fields['publish_down'] = null;
-
-		if (!$row->bind($fields))
-		{
-			$this->addComponentMessage($row->getError(), 'error');
-			$this->editTask($row);
-			return;
-		}
-
-		// Store new content
-		if (!$row->store(true))
-		{
-			$this->addComponentMessage($row->getError(), 'error');
-			$this->editTask($row);
-			return;
-		}
-
-		JRequest::setVar('tmpl', 'component');
-
-		if ($this->getError())
-		{
-			echo '<p class="error">' . $this->getError() . '</p>';
-		}
-		else
-		{
-			echo '<p class="message">' . JText::_('COM_TOOLS_ITEM_SAVED') . '</p>';
-		}
-	}
-
-	/**
-	 * Delete zone entry
-	 *
-	 * @return     void
-	 */
-	public function removeZoneTask()
-	{
-		// Check for request forgeries
-		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
-
-		// Incoming
-		if ($id = JRequest::getInt('id', false))
-		{
-			$db  = \JFactory::getDbo();
-			$row = new ToolVersionZones($db);
-			$row->load($id);
-
-			if (!$row->delete())
-			{
-				JError::raiseError(500, $row->getError());
-				return;
-			}
-		}
-
-		$this->setRedirect(
-			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&tmpl=component&task=displayZones&version=' . JRequest::getInt('version', 0),
-			JText::_('COM_TOOLS_ITEM_DELETED'),
-			'message'
-		);
-	}
-}
\ No newline at end of file
+}
