@@ -107,10 +107,10 @@ switch ($this->level)
 		$html .= '<h3>'.JText::_('COM_RESOURCES').' '.ResourcesHtml::formSelect('sortby', $sortbys, $this->bits['sortby'], '" onchange="javascript:HUB.TagBrowser.changeSort();"').'</h3>';
 		$html .= '<ul id="ulitems">';
 		if ($tools && count($tools) > 0) {
-			//$database = JFactory::getDBO();
+			//$database =& JFactory::getDBO();
 			foreach ($tools as $tool)
 			{
-				$tool->title = \Hubzero\Utility\String::truncate($tool->title, 40);
+				$tool->title = Hubzero_View_Helper_Html::shortenText($tool->title, 40, 0);
 
 				$supported = null;
 				if ($this->bits['supportedtag']) {
@@ -161,12 +161,12 @@ switch ($this->level)
 		$config = $this->bits['config'];
 		$authorized = $this->bits['authorized'];
 
-		$database = JFactory::getDBO();
-
 		$statshtml = '';
 		if ($params->get('show_ranking')) {
 			$helper->getLastCitationDate();
 
+			$database =& JFactory::getDBO();
+
 			if ($resource->type == 7) {
 				$stats = new ToolStats($database, $resource->id, $resource->type, $resource->rating, $helper->citationsCount, $helper->lastCitationDate);
 			} else {
@@ -189,29 +189,28 @@ switch ($this->level)
 			case 0:
 			default: $html .= ' class="public"'; break;
 		}
-		$html .= '><a href="'.$sef.'">'.$this->escape(stripslashes($resource->title)).'</a></h4>';
-		$html .= '<p>'.\Hubzero\Utility\String::truncate(stripslashes($resource->introtext), 400).' &nbsp; <a href="'.$sef.'">'.JText::_('COM_RESOURCES_LEARN_MORE').'</a></p>';
+		$html .= '><a href="'.$sef.'">'.Hubzero_View_Helper_Html::xhtml(stripslashes($resource->title)).'</a></h4>';
+		$html .= '<p>'.Hubzero_View_Helper_Html::shortenText(stripslashes($resource->introtext), 400, 0).' &nbsp; <a href="'.$sef.'">'.JText::_('COM_RESOURCES_LEARN_MORE').'</a></p>';
 
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if (!$juser->get('guest')) {
-			$xgroups = \Hubzero\User\Helper::getGroups($juser->get('id'), 'all');
+			ximport('Hubzero_User_Helper');
+			$xgroups = Hubzero_User_Helper::getGroups($juser->get('id'), 'all');
 			// Get the groups the user has access to
 			$usersgroups = ResourcesControllerResources::getUsersGroups($xgroups);
 		} else {
 			$usersgroups = array();
 		}
 
-		$helper->getFirstChild();
-
 		if ($resource->access == 3 && !in_array($resource->group_owner, $usersgroups) && !$authorized) {
 			$ghtml = JText::_('You must be logged in and a member of one of the following groups to access the full resource:').' ';
 			$allowedgroups = $resource->getGroups();
 			foreach ($allowedgroups as $allowedgroup)
 			{
-				$ghtml .= '<a href="'.JRoute::_('index.php?option=com_groups&cn='.$allowedgroup).'">'.$allowedgroup.'</a>, ';
+				$ghtml .= '<a href="'.JRoute::_('index.php?option=com_groups&gid='.$allowedgroup).'">'.$allowedgroup.'</a>, ';
 			}
 			$ghtml = substr($ghtml,0,strlen($ghtml) - 2);
-			$html .= '<p class="warning">' . $ghtml . '</p>' ."\n";
+			$html .= ResourcesHtml::warning( $ghtml )."\n";
 		} else {
 			if ($helper->firstChild || $resource->type == 7) {
 				$html .= $primary_child;
@@ -229,17 +228,11 @@ switch ($this->level)
 			include_once(JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'tables'.DS.'audience.level.php');
 			$ra = new ResourceAudience( $database );
 			$audience = $ra->getAudience($resource->id, 0, 1, 4);
-
-			$view = $this->view('_audience', 'view')
-						->set('audience', $audience)
-						->set('showtips', 0)
-						->set('numlevels', 4)
-						->set('audiencelink', $params->get('audiencelink'));
-			$xtra .= $view->loadTemplate();
+			$xtra .= ResourcesHtml::showSkillLevel($audience, 0, 4, $params->get('audiencelink'));
 		}
 		if ($this->bits['supportedtag'] && $supported) {
 			include_once(JPATH_ROOT.DS.'components'.DS.'com_tags'.DS.'helpers'.DS.'handler.php');
-			$tag = new TagsTableTag( $database );
+			$tag = new TagsTag( $database );
 			$tag->loadTag($config->get('supportedtag'));
 
 			$sl = $config->get('supportedlink');
@@ -253,15 +246,11 @@ switch ($this->level)
 		}
 
 		if ($params->get('show_metadata')) {
-			$view = $this->view('_metadata', 'view');
-			$view->option = 'com_resources';
-			$view->sections = $sections;
-			$view->model = ResourcesModelResource::getInstance($resource->id);
-
-			$html .= $view->loadTemplate();
+			$html .= ResourcesHtml::metadata($params, $resource->ranking, $statshtml, $resource->id, $sections, $xtra);
 		}
 		$html .= '<input type="hidden" name="rid" id="rid" value="'.$resource->id.'" /></li>';
-		$html .= '</ul>';
+		$html .= '</ul><script type="text/javascript">HUB.Base.popups();HUB.Base.launchTool();</script>';
 	break;
 }
 echo $html;
+?>
\ No newline at end of file
