@@ -34,8 +34,54 @@ defined('_JEXEC') or die( 'Restricted access' );
 /**
  * Module class for displaying a YouTube feed
  */
-class modFeedYoutubeHelper extends \Hubzero\Module\Module
+class modFeedYoutubeHelper extends JObject
 {
+	/**
+	 * Container for properties
+	 * 
+	 * @var array
+	 */
+	private $attributes = array();
+
+	/**
+	 * Constructor
+	 * 
+	 * @param      object $this->params JParameter
+	 * @param      object $module Database row
+	 * @return     void
+	 */
+	public function __construct($params, $module)
+	{
+		$this->params = $params;
+		$this->module = $module;
+	}
+
+	/**
+	 * Set a property
+	 * 
+	 * @param      string $property Name of property to set
+	 * @param      mixed  $value    Value to set property to
+	 * @return     void
+	 */
+	public function __set($property, $value)
+	{
+		$this->attributes[$property] = $value;
+	}
+
+	/**
+	 * Get a property
+	 * 
+	 * @param      string $property Name of property to retrieve
+	 * @return     mixed
+	 */
+	public function __get($property)
+	{
+		if (isset($this->attributes[$property])) 
+		{
+			return $this->attributes[$property];
+		}
+	}
+
 	/**
 	 * Display module contents
 	 * 
@@ -54,23 +100,22 @@ class modFeedYoutubeHelper extends \Hubzero\Module\Module
 
 		if (!$options['rssUrl'])
 		{
-			echo '<p class="warning">' . JText::_('MOD_FEED_YOUTUBE_ERROR_NO_URL') . '</p>';
+			echo '<p class="warning">' . JText::_('No feed URL specified.') . '</p>';
 			return;
 		}
 
-		$rssDoc = JFactory::getXMLparser('RSS', $options);
+		$rssDoc =& JFactory::getXMLparser('RSS', $options);
 
 		$this->feed = new stdclass();
 
 		if ($rssDoc != false)
 		{
 			// channel header and link
-			$this->feed->title        = $rssDoc->get_title();
-			$this->feed->link         = $rssDoc->get_link();
-			$this->feed->description  = $rssDoc->get_description();
+			$this->this->feed->title        = $rssDoc->get_title();
+			$this->this->feed->link         = $rssDoc->get_link();
+			$this->this->feed->description  = $rssDoc->get_description();
 
 			// channel image if exists
-			$this->feed->image        = new stdClass();
 			$this->feed->image->url   = $rssDoc->get_image_url();
 			$this->feed->image->title = $rssDoc->get_image_title();
 
@@ -78,14 +123,14 @@ class modFeedYoutubeHelper extends \Hubzero\Module\Module
 			$items = $rssDoc->get_items();
 
 			// feed elements
-			if ($this->params->get('pick_random', 0))
+			if ($this->params->get('pick_random', 0)) 
 			{
 				// randomize items
 				shuffle($items);
 			}
 			$this->feed->items = array_slice($items, 0, $limit);
-		}
-		else
+		} 
+		else 
 		{
 			$this->feed = false;
 		}
